@@ -17,15 +17,17 @@ if ( !function_exists('dbg_error_log') ) {
   * Otherwise, the first parameter is a "component" name, and will only be logged
   * if $c->dbg["component"] is set to some non-null value.
   *
-  * If you want to see every log message then $c->dbg["ALL"] can be set, to
-  * override the debugging status of the individual components.
+  * If you want to see every log message then $c->dbg["ALL"] can be set, and
+  * then individual components can be set to zero to selectively ignore them.
+  * Additionally, log messages can be filtered by remote IP or username by populating
+  * the $c->dbg_filter["remoteIP"][] and $c->dbg_filter["authenticatedUser"][] arrays.
   *
   * @var string $component The component to identify itself, or "ERROR", or "LOG:component"
   * @var string $format A format string for the log message
   * @var [string $parameter ...] Parameters for the format string.
   */
   function dbg_error_log() {
-    global $c;
+    global $c, $session;
     $args = func_get_args();
     $type = "DBG";
     $component = array_shift($args);
@@ -42,6 +44,16 @@ if ( !function_exists('dbg_error_log') ) {
     }
     else if ( !isset($c->dbg[strtolower($component)]) ) return;
 
+    /* ignore noisy components by setting $c->dbg['foo'] = 0; */
+    if ( isset($c->dbg[strtolower($component)]) && $c->dbg[strtolower($component)] === 0 ) return;
+
+    /* filter by remote IP or logged-in user */
+    if ( isset($c->dbg_filter["remoteIP"]) && !in_array($_SERVER['REMOTE_ADDR'], $c->dbg_filter["remoteIP"]) ) return;
+    if ( isset($c->dbg_filter["authenticatedUser"]) ) {
+        if ( !isset($session->username) ) return;
+        if ( !in_array($session->username, $c->dbg_filter["authenticatedUser"]) ) return;
+    }
+
     $argc = func_num_args();
     if ( 2 <= $argc ) {
       $format = array_shift($args);
@@ -66,19 +78,19 @@ if ( !function_exists('fatal') ) {
       $format = "%s";
     }
     @error_log( $c->sysabbr.": FATAL: $component:". vsprintf( $format, $args ) );
-    
+
     @error_log( "================= Stack Trace ===================" );
-	
-  	$trace = array_reverse(debug_backtrace());
+
+    $trace = array_reverse(debug_backtrace());
     array_pop($trace);
     foreach( $trace AS $k => $v ) {
- 	  @error_log( sprintf(" ===>  %s[%d] calls %s%s%s()",
-	               $v['file'],
-	               $v['line'],
-	               (isset($v['class'])?$v['class']:''),
-	               (isset($v['type'])?$v['type']:''),
-	               (isset($v['function'])?$v['function']:'')
-	      ));
+      @error_log( sprintf(" ===>  %s[%d] calls %s%s%s()",
+                    $v['file'],
+                    $v['line'],
+                    (isset($v['class'])?$v['class']:''),
+                    (isset($v['type'])?$v['type']:''),
+                    (isset($v['function'])?$v['function']:'')
+      ));
     }
     echo "Fatal Error";
     exit();
@@ -101,19 +113,19 @@ if ( !function_exists('trace_bug') ) {
       $format = "%s";
     }
     @error_log( $c->sysabbr.": BUG: $component:". vsprintf( $format, $args ) );
-    
+
     @error_log( "================= Stack Trace ===================" );
-	
-  	$trace = array_reverse(debug_backtrace());
+
+    $trace = array_reverse(debug_backtrace());
     array_pop($trace);
     foreach( $trace AS $k => $v ) {
- 	  @error_log( sprintf(" ===>  %s[%d] calls %s%s%s()",
-	               $v['file'],
-	               $v['line'],
-	               (isset($v['class'])?$v['class']:''),
-	               (isset($v['type'])?$v['type']:''),
-	               (isset($v['function'])?$v['function']:'')
-	      ));
+      @error_log( sprintf(" ===>  %s[%d] calls %s%s%s()",
+                    $v['file'],
+                    $v['line'],
+                    (isset($v['class'])?$v['class']:''),
+                    (isset($v['type'])?$v['type']:''),
+                    (isset($v['function'])?$v['function']:'')
+      ));
     }
   }
 }
@@ -225,6 +237,7 @@ if ( !function_exists("session_salted_sha1") ) {
 
 
 if ( !function_exists("session_validate_password") ) {
+
   /**
   * Checks what a user entered against the actual password on their account.
   * @param string $they_sent What the user entered.
@@ -232,11 +245,22 @@ if ( !function_exists("session_validate_password") ) {
   * @return boolean Whether or not the users attempt matches what is already on file.
   */
   function session_validate_password( $they_sent, $we_have ) {
+    global $c;
     if ( preg_match('/^\*\*.+$/', $we_have ) ) {
       //  The "forced" style of "**plaintext" to allow easier admin setting
       return ( "**$they_sent" == $we_have );
     }
 
+    if ( isset($c->wp_includes) && substring($we_have,0,1) == '$' ) {
+      // Include Wordpress password handling, if it's in the path.
+      @require_once($c->wp_includes .'/class-phpass.php');
+
+      if ( class_exists('PasswordHash') ) {
+        $wp_hasher = new PasswordHash(8, true);
+        return $wp_hasher->CheckPassword($password, $hash);
+      }
+    }
+
     if ( preg_match('/^\*(.+)\*{[A-Z]+}.+$/', $we_have, $regs ) ) {
       if ( function_exists("session_salted_sha1") ) {
         // A nicely salted sha1sum like "*<salt>*{SSHA}<salted_sha1>"
@@ -463,22 +487,22 @@ if ( !function_exists("param_to_global") ) {
 }
 
 
-if ( !function_exists("get_fields") ) {
+if ( !function_exists("awl_get_fields") ) {
   /**
   * @var array $_AWL_field_cache is a cache of the field names for a table
   */
   $_AWL_field_cache = array();
-  
+
   /**
   * Get the names of the fields for a particular table
   * @param string $tablename The name of the table.
   * @return array of string The public fields in the table.
   */
-  function get_fields( $tablename ) {
+  function awl_get_fields( $tablename ) {
     global $_AWL_field_cache;
 
     if ( !isset($_AWL_field_cache[$tablename]) ) {
-      dbg_error_log( "core", ":get_fields: Loading fields for table '$tablename'" );
+      dbg_error_log( "core", ":awl_get_fields: Loading fields for table '$tablename'" );
       $qry = new AwlQuery();
       $db = $qry->GetConnection();
       $qry->SetSQL($db->GetFields($tablename));
@@ -578,13 +602,15 @@ if ( !function_exists("force_utf8") ) {
 }
 
 
+$timezone_identifiers_list_cache = timezone_identifiers_list();
+
 /**
 * Try and extract something like "Pacific/Auckland" or "America/Indiana/Indianapolis" if possible.
 */
 function olson_from_tzstring( $tzstring ) {
-  global $c;
-  
-  if ( function_exists('timezone_identifiers_list') && in_array($tzstring,timezone_identifiers_list()) ) return $tzstring;
+  global $c, $timezone_identifiers_list_cache;
+
+  if ( in_array($tzstring,$timezone_identifiers_list_cache) ) return $tzstring;
   if ( preg_match( '{((Antarctica|America|Africa|Atlantic|Asia|Australia|Indian|Europe|Pacific)/(([^/]+)/)?[^/]+)$}', $tzstring, $matches ) ) {
 //    dbg_error_log( 'INFO', 'Found timezone "%s" from string "%s"', $matches[1], $tzstring );
     return $matches[1];
@@ -612,9 +638,9 @@ function olson_from_tzstring( $tzstring ) {
          return 'America/Phoenix';
          break;
     default:
-         if ( isset($c->timezone_translations) && is_array($c->timezone_translations) 
+         if ( isset($c->timezone_translations) && is_array($c->timezone_translations)
                       && !empty($c->timezone_translations[$tzstring]) )
-           return $c->timezone_translations[$tzstring];      
+           return $c->timezone_translations[$tzstring];
   }
   return null;
 }
@@ -648,10 +674,10 @@ if ( !function_exists("gzdecode") ) {
       if ( is_resource($process) ) {
         fwrite($pipes[0],$instring);
         fclose($pipes[0]);
-        
+
         $outstring = stream_get_contents($pipes[1]);
         fclose($pipes[1]);
-        
+
         proc_close($process);
         return $outstring;
       }
@@ -674,6 +700,6 @@ if ( !function_exists("gzdecode") ) {
  */
 function awl_version() {
   global $c;
-$c->awl_library_version = 0.51;
+$c->awl_library_version = 0.61;
   return $c->awl_library_version;
-}
\ No newline at end of file
+}
