@@ -57,24 +57,24 @@ class AwlDBDialect {
    * Preferred is "Sun, 06 Nov 1994 08:49:37 GMT" so we do that.
    */
   const HttpDateFormat = "'Dy, DD Mon IYYY HH24:MI:SS \"GMT\"'";
-  
+
   /**
    * A PostgreSQL Date Format string suitable for returning iCal dates
   */
   const SqlDateFormat = "'YYYYMMDD\"T\"HH24MISS'";
-  
+
   /**
    * A PostgreSQL Date Format string suitable for returning dates which
    * have been cast to UTC
   */
   const SqlUTCFormat = "'YYYYMMDD\"T\"HH24MISS\"Z\"'";
-  
+
   /**
    * A PostgreSQL Date Format string suitable for returning iCal durations
    *  - this doesn't work for negative intervals, but events should not have such!
   */
   const SqlDurationFormat = "'\"PT\"HH24\"H\"MI\"M\"'";
-  
+
   /**
   * Parses the connection string to ascertain the database dialect. Returns true if the dialect is supported
   * and fails if the dialect is not supported. All code to support any given database should be within in an
@@ -164,11 +164,11 @@ class AwlDBDialect {
 
     switch ( $this->dialect ) {
       case 'pgsql':
-      	list( $schema, $table ) = explode('.', $tablename_string, 2);
-      	if ( empty($table) ) {
-      		$table = $tablename_string;
-      		$schema = null;
-      	}
+        list( $schema, $table ) = explode('.', $tablename_string, 2);
+        if ( empty($table) ) {
+          $table = $tablename_string;
+          $schema = null;
+        }
 
         $sql = 'SELECT f.attname AS fieldname, t.typname AS typename, f.atttypmod AS precision FROM pg_attribute f';
         $sql .= ' JOIN pg_class c ON ( f.attrelid = c.oid )';
@@ -177,7 +177,7 @@ class AwlDBDialect {
         $sql .= ' WHERE relname = '.$this->Quote($table,PDO::PARAM_STR).' AND attnum >= 0 ';
         if ( isset($schema) ) $sql .= ' AND ns.nspname = '.$this->Quote($schema,PDO::PARAM_STR);
         $sql .= ' ORDER BY f.attnum';
-        error_log($sql);
+        dbg_error_log($sql);
         return $sql;
     }
   }
