@@ -134,7 +134,7 @@ class EntryField
   * @param text $current_value The current value to use to initialise the
   *                     field.   Optional.
   */
-  function EntryField( $intype, $inname, $attributes="", $current_value="" )
+  function __construct( $intype, $inname, $attributes="", $current_value="" )
   {
     $this->ftype = $intype;
     $this->fname = $inname;
@@ -170,7 +170,7 @@ class EntryField
       case "select":
         $r .= "select name=\"$this->fname\"%%attributes%%>";
         reset( $this->attributes );
-        while( list($k,$v) = each( $this->attributes ) ) {
+        foreach( $this->attributes as $k => $v ) {
           if ( substr($k, 0, 1) != '_' ) continue;
           if ( $k == '_help' ) continue;
           $k = substr($k,1);
@@ -184,7 +184,7 @@ class EntryField
       case "lookup":
         $r .= "select name=\"$this->fname\"%%attributes%%>";
         reset( $this->attributes );
-        while( list($k,$v) = each( $this->attributes ) ) {
+        foreach( $this->attributes as $k => $v ) {
           if ( substr($k, 0, 1) != '_' ) continue;
           $k = substr($k,1);
           if ( $k == 'help' || $k == "sql" || $k == "type" ) continue;
@@ -263,7 +263,7 @@ class EntryField
     // Now process the generic attributes
     reset( $this->attributes );
     $attribute_values = "";
-    while( list($k,$v) = each( $this->attributes ) ) {
+    foreach( $this->attributes as $k => $v ) {
       if ( $k == '_readonly' ) $attribute_values .= " readonly";
       else if ( $k == '_disabled' ) $attribute_values .= " disabled";
       if ( substr($k, 0, 1) == '_' ) continue;
@@ -321,7 +321,7 @@ class EntryField
     }
     return $result;
    }
-  
+
 }
 
 /**
@@ -391,7 +391,7 @@ class EntryForm
   * @param objectref $record A reference to the database object we are displaying / editing.
   * @param boolean $editmode Whether we are editing.
   */
-  function EntryForm( $action, &$record, $editing=false )
+  function __construct( $action, &$record, $editing=false )
   {
     $this->action   = $action;
     $this->record   = &$record;
@@ -483,7 +483,7 @@ class EntryForm
     // Now process the generic attributes
     reset( $extra_attributes );
     $attribute_values = "";
-    while( list($k,$v) = each( $extra_attributes ) ) {
+    foreach( $extra_attributes as $k => $v ) {
       $attribute_values .= " $k=\"".htmlspecialchars($v)."\"";
     }
     return "<form$attribute_values>\n";
@@ -655,7 +655,7 @@ class EntryForm
     $prompt = "<select name=\"$prompt_name\">";
 
     reset($prompt_options);
-    while( list($k,$v) = each($prompt_options) ) {
+    foreach( $prompt_options as $k => $v ) {
       $selected = ( ( $k == $default_prompt ) ? ' selected="selected"' : '' );
       $nextrow = "<option value=\"$k\"$selected>$v</option>";
       if ( preg_match('/&/', $nextrow) ) $nextrow = preg_replace( '/&/', '&amp;', $nextrow);
